import { FileBase, FileBaseOptions, IResolver } from './file';
import { Project } from './project';
/**
 * (experimental) Options for `ObjectFile`.
 *
 * @experimental
 */
export interface ObjectFileOptions extends FileBaseOptions {
    /**
     * (experimental) The object that will be serialized.
     *
     * You can modify the object's contents
     * before synthesis.
     *
     * @default {} an empty object (use `file.obj` to mutate).
     * @experimental
     */
    readonly obj?: any;
    /**
     * (experimental) Omits empty objects and arrays.
     *
     * @default false
     * @experimental
     */
    readonly omitEmpty?: boolean;
}
/**
 * (experimental) Represents an Object file.
 *
 * @experimental
 */
export declare abstract class ObjectFile extends FileBase {
    /**
     * (experimental) The output object.
     *
     * This object can be mutated until the project is
     * synthesized.
     *
     * @experimental
     */
    readonly obj: object;
    /**
     * (experimental) Indicates if empty objects and arrays are omitted from the output object.
     *
     * @experimental
     */
    readonly omitEmpty: boolean;
    /**
     * @experimental
     */
    constructor(project: Project, filePath: string, options: ObjectFileOptions);
    /**
     * (experimental) Implemented by derived classes and returns the contents of the file to emit.
     *
     * @experimental
     */
    protected synthesizeContent(resolver: IResolver): string | undefined;
}
